# ThingsBoard Monitor

> Note: 
> 
> This is not an official project of the [
ThingsBoard](https://thingsboard.io/) authors! Please refer to [ThingsBoard - Open-source IoT Platform](https://github.com/thingsboard) for official ThingsBoard projects!

The _ThingsBoard Monitor_ package provides some classes to create an application monitoring and controlling
one or more ThingsBoard endpoints (devices).
